# Documentation for `PhotonRegistry`
::: photonai.base.PhotonRegistry
    selection:
      members:
        - __init__
        - get_package_info
        - register
        - info
        - list_available_elements
        - delete
